@@ -1,7 +1,3 @@
-# coding: utf-8
-from __future__ import unicode_literals
-
-
 from .common import InfoExtractor
 from ..compat import compat_str
 from ..utils import (
@@ -93,7 +89,7 @@ class VineIE(InfoExtractor):
 
         username = data.get('username')
 
-        alt_title = format_field(username, template='Vine by %s')
+        alt_title = format_field(username, None, 'Vine by %s')
 
         return {
             'id': video_id,
